Macros
- call
- A macro that helps make JNI Method calls less verbose and easier to use in Rust.
- class
- Get the class Object for some Class.
The returned object has type
java.lang.Classand is wrapped withJClass. - eprintln
- Print error. See
std::eprintln!. - field
- Access or Set the value of a Java Field.
- jni_fn
- Define a function in Rust that can be called from external Java code.
- new
- Call a Java Class’ constructor.
- println
- Print output. See
std::println!. - singleton
- Get the instance Object of a Singleton Class by calling the
getInstance()static method on the Class.